@@ -16,8 +16,10 @@ from datetime import datetime
 from typing import IO, Any, Dict, List, Union
 
 from .literals import (
+    ApplicationModeType,
     ApplicationRestoreTypeType,
     ApplicationStatusType,
+    ArtifactTypeType,
     CodeContentTypeType,
     ConfigurationTypeType,
     InputStartingPositionType,
@@ -57,6 +59,9 @@ __all__ = (
     "ApplicationSummaryTypeDef",
     "ApplicationVersionSummaryTypeDef",
     "CSVMappingParametersTypeDef",
+    "CatalogConfigurationDescriptionTypeDef",
+    "CatalogConfigurationTypeDef",
+    "CatalogConfigurationUpdateTypeDef",
     "CheckpointConfigurationDescriptionTypeDef",
     "CheckpointConfigurationTypeDef",
     "CheckpointConfigurationUpdateTypeDef",
@@ -68,11 +73,16 @@ __all__ = (
     "CodeContentUpdateTypeDef",
     "CreateApplicationPresignedUrlResponseTypeDef",
     "CreateApplicationResponseTypeDef",
+    "CustomArtifactConfigurationDescriptionTypeDef",
+    "CustomArtifactConfigurationTypeDef",
     "DeleteApplicationCloudWatchLoggingOptionResponseTypeDef",
     "DeleteApplicationInputProcessingConfigurationResponseTypeDef",
     "DeleteApplicationOutputResponseTypeDef",
     "DeleteApplicationReferenceDataSourceResponseTypeDef",
     "DeleteApplicationVpcConfigurationResponseTypeDef",
+    "DeployAsApplicationConfigurationDescriptionTypeDef",
+    "DeployAsApplicationConfigurationTypeDef",
+    "DeployAsApplicationConfigurationUpdateTypeDef",
     "DescribeApplicationResponseTypeDef",
     "DescribeApplicationSnapshotResponseTypeDef",
     "DescribeApplicationVersionResponseTypeDef",
@@ -85,6 +95,9 @@ __all__ = (
     "FlinkApplicationConfigurationTypeDef",
     "FlinkApplicationConfigurationUpdateTypeDef",
     "FlinkRunConfigurationTypeDef",
+    "GlueDataCatalogConfigurationDescriptionTypeDef",
+    "GlueDataCatalogConfigurationTypeDef",
+    "GlueDataCatalogConfigurationUpdateTypeDef",
     "InputDescriptionTypeDef",
     "InputLambdaProcessorDescriptionTypeDef",
     "InputLambdaProcessorTypeDef",
@@ -119,6 +132,7 @@ __all__ = (
     "ListApplicationsResponseTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "MappingParametersTypeDef",
+    "MavenReferenceTypeDef",
     "MonitoringConfigurationDescriptionTypeDef",
     "MonitoringConfigurationTypeDef",
     "MonitoringConfigurationUpdateTypeDef",
@@ -142,6 +156,9 @@ __all__ = (
     "RunConfigurationUpdateTypeDef",
     "S3ApplicationCodeLocationDescriptionTypeDef",
     "S3ConfigurationTypeDef",
+    "S3ContentBaseLocationDescriptionTypeDef",
+    "S3ContentBaseLocationTypeDef",
+    "S3ContentBaseLocationUpdateTypeDef",
     "S3ContentLocationTypeDef",
     "S3ContentLocationUpdateTypeDef",
     "S3ReferenceDataSourceDescriptionTypeDef",
@@ -159,6 +176,12 @@ __all__ = (
     "VpcConfigurationDescriptionTypeDef",
     "VpcConfigurationTypeDef",
     "VpcConfigurationUpdateTypeDef",
+    "ZeppelinApplicationConfigurationDescriptionTypeDef",
+    "ZeppelinApplicationConfigurationTypeDef",
+    "ZeppelinApplicationConfigurationUpdateTypeDef",
+    "ZeppelinMonitoringConfigurationDescriptionTypeDef",
+    "ZeppelinMonitoringConfigurationTypeDef",
+    "ZeppelinMonitoringConfigurationUpdateTypeDef",
 )
 
 AddApplicationCloudWatchLoggingOptionResponseTypeDef = TypedDict(
@@ -284,35 +307,25 @@ ApplicationConfigurationDescriptionTypeDef = TypedDict(
         "EnvironmentPropertyDescriptions": "EnvironmentPropertyDescriptionsTypeDef",
         "ApplicationSnapshotConfigurationDescription": "ApplicationSnapshotConfigurationDescriptionTypeDef",
         "VpcConfigurationDescriptions": List["VpcConfigurationDescriptionTypeDef"],
+        "ZeppelinApplicationConfigurationDescription": "ZeppelinApplicationConfigurationDescriptionTypeDef",
     },
     total=False,
 )
 
-_RequiredApplicationConfigurationTypeDef = TypedDict(
-    "_RequiredApplicationConfigurationTypeDef",
-    {
-        "ApplicationCodeConfiguration": "ApplicationCodeConfigurationTypeDef",
-    },
-)
-_OptionalApplicationConfigurationTypeDef = TypedDict(
-    "_OptionalApplicationConfigurationTypeDef",
+ApplicationConfigurationTypeDef = TypedDict(
+    "ApplicationConfigurationTypeDef",
     {
         "SqlApplicationConfiguration": "SqlApplicationConfigurationTypeDef",
         "FlinkApplicationConfiguration": "FlinkApplicationConfigurationTypeDef",
         "EnvironmentProperties": "EnvironmentPropertiesTypeDef",
+        "ApplicationCodeConfiguration": "ApplicationCodeConfigurationTypeDef",
         "ApplicationSnapshotConfiguration": "ApplicationSnapshotConfigurationTypeDef",
         "VpcConfigurations": List["VpcConfigurationTypeDef"],
+        "ZeppelinApplicationConfiguration": "ZeppelinApplicationConfigurationTypeDef",
     },
     total=False,
 )
 
-
-class ApplicationConfigurationTypeDef(
-    _RequiredApplicationConfigurationTypeDef, _OptionalApplicationConfigurationTypeDef
-):
-    pass
-
-
 ApplicationConfigurationUpdateTypeDef = TypedDict(
     "ApplicationConfigurationUpdateTypeDef",
     {
@@ -322,6 +335,7 @@ ApplicationConfigurationUpdateTypeDef = TypedDict(
         "EnvironmentPropertyUpdates": "EnvironmentPropertyUpdatesTypeDef",
         "ApplicationSnapshotConfigurationUpdate": "ApplicationSnapshotConfigurationUpdateTypeDef",
         "VpcConfigurationUpdates": List["VpcConfigurationUpdateTypeDef"],
+        "ZeppelinApplicationConfigurationUpdate": "ZeppelinApplicationConfigurationUpdateTypeDef",
     },
     total=False,
 )
@@ -350,6 +364,7 @@ _OptionalApplicationDetailTypeDef = TypedDict(
         "ApplicationVersionRolledBackFrom": int,
         "ConditionalToken": str,
         "ApplicationVersionRolledBackTo": int,
+        "ApplicationMode": ApplicationModeType,
     },
     total=False,
 )
@@ -418,8 +433,8 @@ ApplicationSnapshotConfigurationUpdateTypeDef = TypedDict(
     },
 )
 
-ApplicationSummaryTypeDef = TypedDict(
-    "ApplicationSummaryTypeDef",
+_RequiredApplicationSummaryTypeDef = TypedDict(
+    "_RequiredApplicationSummaryTypeDef",
     {
         "ApplicationName": str,
         "ApplicationARN": str,
@@ -428,6 +443,20 @@ ApplicationSummaryTypeDef = TypedDict(
         "RuntimeEnvironment": RuntimeEnvironmentType,
     },
 )
+_OptionalApplicationSummaryTypeDef = TypedDict(
+    "_OptionalApplicationSummaryTypeDef",
+    {
+        "ApplicationMode": ApplicationModeType,
+    },
+    total=False,
+)
+
+
+class ApplicationSummaryTypeDef(
+    _RequiredApplicationSummaryTypeDef, _OptionalApplicationSummaryTypeDef
+):
+    pass
+
 
 ApplicationVersionSummaryTypeDef = TypedDict(
     "ApplicationVersionSummaryTypeDef",
@@ -445,6 +474,27 @@ CSVMappingParametersTypeDef = TypedDict(
     },
 )
 
+CatalogConfigurationDescriptionTypeDef = TypedDict(
+    "CatalogConfigurationDescriptionTypeDef",
+    {
+        "GlueDataCatalogConfigurationDescription": "GlueDataCatalogConfigurationDescriptionTypeDef",
+    },
+)
+
+CatalogConfigurationTypeDef = TypedDict(
+    "CatalogConfigurationTypeDef",
+    {
+        "GlueDataCatalogConfiguration": "GlueDataCatalogConfigurationTypeDef",
+    },
+)
+
+CatalogConfigurationUpdateTypeDef = TypedDict(
+    "CatalogConfigurationUpdateTypeDef",
+    {
+        "GlueDataCatalogConfigurationUpdate": "GlueDataCatalogConfigurationUpdateTypeDef",
+    },
+)
+
 CheckpointConfigurationDescriptionTypeDef = TypedDict(
     "CheckpointConfigurationDescriptionTypeDef",
     {
@@ -587,6 +637,38 @@ CreateApplicationResponseTypeDef = TypedDict(
     },
 )
 
+CustomArtifactConfigurationDescriptionTypeDef = TypedDict(
+    "CustomArtifactConfigurationDescriptionTypeDef",
+    {
+        "ArtifactType": ArtifactTypeType,
+        "S3ContentLocationDescription": "S3ContentLocationTypeDef",
+        "MavenReferenceDescription": "MavenReferenceTypeDef",
+    },
+    total=False,
+)
+
+_RequiredCustomArtifactConfigurationTypeDef = TypedDict(
+    "_RequiredCustomArtifactConfigurationTypeDef",
+    {
+        "ArtifactType": ArtifactTypeType,
+    },
+)
+_OptionalCustomArtifactConfigurationTypeDef = TypedDict(
+    "_OptionalCustomArtifactConfigurationTypeDef",
+    {
+        "S3ContentLocation": "S3ContentLocationTypeDef",
+        "MavenReference": "MavenReferenceTypeDef",
+    },
+    total=False,
+)
+
+
+class CustomArtifactConfigurationTypeDef(
+    _RequiredCustomArtifactConfigurationTypeDef, _OptionalCustomArtifactConfigurationTypeDef
+):
+    pass
+
+
 DeleteApplicationCloudWatchLoggingOptionResponseTypeDef = TypedDict(
     "DeleteApplicationCloudWatchLoggingOptionResponseTypeDef",
     {
@@ -633,6 +715,27 @@ DeleteApplicationVpcConfigurationResponseTypeDef = TypedDict(
     total=False,
 )
 
+DeployAsApplicationConfigurationDescriptionTypeDef = TypedDict(
+    "DeployAsApplicationConfigurationDescriptionTypeDef",
+    {
+        "S3ContentLocationDescription": "S3ContentBaseLocationDescriptionTypeDef",
+    },
+)
+
+DeployAsApplicationConfigurationTypeDef = TypedDict(
+    "DeployAsApplicationConfigurationTypeDef",
+    {
+        "S3ContentLocation": "S3ContentBaseLocationTypeDef",
+    },
+)
+
+DeployAsApplicationConfigurationUpdateTypeDef = TypedDict(
+    "DeployAsApplicationConfigurationUpdateTypeDef",
+    {
+        "S3ContentLocationUpdate": "S3ContentBaseLocationUpdateTypeDef",
+    },
+)
+
 DescribeApplicationResponseTypeDef = TypedDict(
     "DescribeApplicationResponseTypeDef",
     {
@@ -734,6 +837,28 @@ FlinkRunConfigurationTypeDef = TypedDict(
     total=False,
 )
 
+GlueDataCatalogConfigurationDescriptionTypeDef = TypedDict(
+    "GlueDataCatalogConfigurationDescriptionTypeDef",
+    {
+        "DatabaseARN": str,
+    },
+)
+
+GlueDataCatalogConfigurationTypeDef = TypedDict(
+    "GlueDataCatalogConfigurationTypeDef",
+    {
+        "DatabaseARN": str,
+    },
+)
+
+GlueDataCatalogConfigurationUpdateTypeDef = TypedDict(
+    "GlueDataCatalogConfigurationUpdateTypeDef",
+    {
+        "DatabaseARNUpdate": str,
+    },
+    total=False,
+)
+
 InputDescriptionTypeDef = TypedDict(
     "InputDescriptionTypeDef",
     {
@@ -1129,6 +1254,15 @@ MappingParametersTypeDef = TypedDict(
     total=False,
 )
 
+MavenReferenceTypeDef = TypedDict(
+    "MavenReferenceTypeDef",
+    {
+        "GroupId": str,
+        "ArtifactId": str,
+        "Version": str,
+    },
+)
+
 MonitoringConfigurationDescriptionTypeDef = TypedDict(
     "MonitoringConfigurationDescriptionTypeDef",
     {
@@ -1467,6 +1601,70 @@ S3ConfigurationTypeDef = TypedDict(
     },
 )
 
+_RequiredS3ContentBaseLocationDescriptionTypeDef = TypedDict(
+    "_RequiredS3ContentBaseLocationDescriptionTypeDef",
+    {
+        "BucketARN": str,
+    },
+)
+_OptionalS3ContentBaseLocationDescriptionTypeDef = TypedDict(
+    "_OptionalS3ContentBaseLocationDescriptionTypeDef",
+    {
+        "BasePath": str,
+    },
+    total=False,
+)
+
+
+class S3ContentBaseLocationDescriptionTypeDef(
+    _RequiredS3ContentBaseLocationDescriptionTypeDef,
+    _OptionalS3ContentBaseLocationDescriptionTypeDef,
+):
+    pass
+
+
+_RequiredS3ContentBaseLocationTypeDef = TypedDict(
+    "_RequiredS3ContentBaseLocationTypeDef",
+    {
+        "BucketARN": str,
+    },
+)
+_OptionalS3ContentBaseLocationTypeDef = TypedDict(
+    "_OptionalS3ContentBaseLocationTypeDef",
+    {
+        "BasePath": str,
+    },
+    total=False,
+)
+
+
+class S3ContentBaseLocationTypeDef(
+    _RequiredS3ContentBaseLocationTypeDef, _OptionalS3ContentBaseLocationTypeDef
+):
+    pass
+
+
+_RequiredS3ContentBaseLocationUpdateTypeDef = TypedDict(
+    "_RequiredS3ContentBaseLocationUpdateTypeDef",
+    {
+        "BucketARNUpdate": str,
+    },
+)
+_OptionalS3ContentBaseLocationUpdateTypeDef = TypedDict(
+    "_OptionalS3ContentBaseLocationUpdateTypeDef",
+    {
+        "BasePathUpdate": str,
+    },
+    total=False,
+)
+
+
+class S3ContentBaseLocationUpdateTypeDef(
+    _RequiredS3ContentBaseLocationUpdateTypeDef, _OptionalS3ContentBaseLocationUpdateTypeDef
+):
+    pass
+
+
 _RequiredS3ContentLocationTypeDef = TypedDict(
     "_RequiredS3ContentLocationTypeDef",
     {
@@ -1692,3 +1890,74 @@ class VpcConfigurationUpdateTypeDef(
     _RequiredVpcConfigurationUpdateTypeDef, _OptionalVpcConfigurationUpdateTypeDef
 ):
     pass
+
+
+_RequiredZeppelinApplicationConfigurationDescriptionTypeDef = TypedDict(
+    "_RequiredZeppelinApplicationConfigurationDescriptionTypeDef",
+    {
+        "MonitoringConfigurationDescription": "ZeppelinMonitoringConfigurationDescriptionTypeDef",
+    },
+)
+_OptionalZeppelinApplicationConfigurationDescriptionTypeDef = TypedDict(
+    "_OptionalZeppelinApplicationConfigurationDescriptionTypeDef",
+    {
+        "CatalogConfigurationDescription": "CatalogConfigurationDescriptionTypeDef",
+        "DeployAsApplicationConfigurationDescription": "DeployAsApplicationConfigurationDescriptionTypeDef",
+        "CustomArtifactsConfigurationDescription": List[
+            "CustomArtifactConfigurationDescriptionTypeDef"
+        ],
+    },
+    total=False,
+)
+
+
+class ZeppelinApplicationConfigurationDescriptionTypeDef(
+    _RequiredZeppelinApplicationConfigurationDescriptionTypeDef,
+    _OptionalZeppelinApplicationConfigurationDescriptionTypeDef,
+):
+    pass
+
+
+ZeppelinApplicationConfigurationTypeDef = TypedDict(
+    "ZeppelinApplicationConfigurationTypeDef",
+    {
+        "MonitoringConfiguration": "ZeppelinMonitoringConfigurationTypeDef",
+        "CatalogConfiguration": "CatalogConfigurationTypeDef",
+        "DeployAsApplicationConfiguration": "DeployAsApplicationConfigurationTypeDef",
+        "CustomArtifactsConfiguration": List["CustomArtifactConfigurationTypeDef"],
+    },
+    total=False,
+)
+
+ZeppelinApplicationConfigurationUpdateTypeDef = TypedDict(
+    "ZeppelinApplicationConfigurationUpdateTypeDef",
+    {
+        "MonitoringConfigurationUpdate": "ZeppelinMonitoringConfigurationUpdateTypeDef",
+        "CatalogConfigurationUpdate": "CatalogConfigurationUpdateTypeDef",
+        "DeployAsApplicationConfigurationUpdate": "DeployAsApplicationConfigurationUpdateTypeDef",
+        "CustomArtifactsConfigurationUpdate": List["CustomArtifactConfigurationTypeDef"],
+    },
+    total=False,
+)
+
+ZeppelinMonitoringConfigurationDescriptionTypeDef = TypedDict(
+    "ZeppelinMonitoringConfigurationDescriptionTypeDef",
+    {
+        "LogLevel": LogLevelType,
+    },
+    total=False,
+)
+
+ZeppelinMonitoringConfigurationTypeDef = TypedDict(
+    "ZeppelinMonitoringConfigurationTypeDef",
+    {
+        "LogLevel": LogLevelType,
+    },
+)
+
+ZeppelinMonitoringConfigurationUpdateTypeDef = TypedDict(
+    "ZeppelinMonitoringConfigurationUpdateTypeDef",
+    {
+        "LogLevelUpdate": LogLevelType,
+    },
+)
